# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-01-05 12:55
from __future__ import unicode_literals

from django.db import migrations, models
import user_media.models


class Migration(migrations.Migration):

    dependencies = [
        ('user_media', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usermediaimage',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to=user_media.models.get_image_file_path, verbose_name='Image'),
        ),
    ]
