{% load staticfiles %}
<script src="{% static "user_media/js/image_upload.js" %}"></script>
<script src="{% static "user_media/js/tmpl.min.js" %}"></script>
<script src="{% static "user_media/js/jquery.fileupload.js" %}"></script>
<script src="{% static "user_media/js/jquery.fileupload-process.js" %}"></script>
<script src="{% static "user_media/js/jquery.fileupload-validate.js" %}"></script>
<script src="{% static "user_media/js/jquery.fileupload-ui.js" %}"></script>